Pipeline
========

.. autoclass:: igua.pipeline.PipelineParameters
   :members:


.. autoclass:: igua.pipeline.PipelineResult
   :members:


.. autoclass:: igua.pipeline.Pipeline
   :members:
   :special-members: __init__

